Method: RubyCurses::Widget#focussed
- Defined in:
- lib/rbhex/core/widgets/rwidget.rb
#focussed ⇒ Object
sometimes inside a container there’s no way of knowing if an individual comp is in focus other than the explicitly set it and inquire . 2010-09-02 14:47 @since 1.1.5 NOTE state takes care of this and is set by form
831 832 833 |
# File 'lib/rbhex/core/widgets/rwidget.rb', line 831 def focussed @focussed end |